@@ -99,23 +99,17 @@ class MinioAgent(ABC):
             else:
                 yield None
 
-    def has_object_been_analysed(self, object_name: str, bucket_name: str) -> bool:
+    def is_already_processed(self, object_name: str, bucket_name: str) -> bool:
         tags = self.client.get_object_tags(bucket_name, object_name)
-        if tags:
-            try:
-                if tags[f"{self.name}-processed"] == "True":
-                    return True
-                else:
-                    return False
-            except KeyError:
-                return False
+        if f"{self.name}-processed" in tags:
+            already_processed = tags[f"{self.name}-processed"]
         else:
-            return False
+            already_processed = False
 
     def filter_objects_todo(
         self, object_names: List[str], bucket_name: str
     ) -> List[str]:
-        return [name for name in object_names if not self.has_object_been_analysed(object_name=name, bucket_name)]
+        return [name for name in object_names if not self.is_already_processed(object_name=name, bucket_name)]
 
     def tag_objects_as_processed(
         self, object_names_processed: List[str], bucket_name: str
